← Back to team overview

launchpad-reviewers team mailing list archive

lp:~allenap/python-oops-twisted/prevent-foot-shooting-bug-869463 into lp:python-oops-twisted

 

Gavin Panella has proposed merging lp:~allenap/python-oops-twisted/prevent-foot-shooting-bug-869463 into lp:python-oops-twisted.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)
Related bugs:
  Bug #869463 in python-oops-twisted: "Eats CPU and memory due to slighly misconfigured OOPSObserver"
  https://bugs.launchpad.net/python-oops-twisted/+bug/869463

For more details, see:
https://code.launchpad.net/~allenap/python-oops-twisted/prevent-foot-shooting-bug-869463/+merge/78502

Ensure that the fallback passed to OOPSObserver is a callable.
-- 
https://code.launchpad.net/~allenap/python-oops-twisted/prevent-foot-shooting-bug-869463/+merge/78502
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~allenap/python-oops-twisted/prevent-foot-shooting-bug-869463 into lp:python-oops-twisted.
=== modified file 'oops_twisted/log.py'
--- oops_twisted/log.py	2011-09-28 09:00:46 +0000
+++ oops_twisted/log.py	2011-10-06 20:42:23 +0000
@@ -36,16 +36,17 @@
         """"Create an OOPSObserver.
 
         :param config: An oops_twisted.Config.
         :param fallback: If supplied, a LogObserver to pass non-failure log
             events to, and to inform (as non-failures) when an OOPS has
             occurred.
         """
         self.config = config
+        assert fallback is None or callable(fallback)
         self.fallback = fallback
 
     def emit(self, eventDict):
         """Handle a twisted log entry.
-        
+
         :return: For testing convenience returns the oops report and a deferred
             which fires after all publication and fallback forwarding has
             occured, though the twisted logging protocol does not need (or
@@ -36,16 +36,17 @@
 
         :param config: An oops_twisted.Config.
-        :param fallback: If supplied, a LogObserver to pass non-failure log
+        :param fallback: If supplied, a callable to pass non-failure log
             events to, and to inform (as non-failures) when an OOPS has
             occurred.